Overlapping Branch and Bound — oBB Documentation

oBB Documentation
next | index

# Overlapping Branch and Bound

Release: 0.6b

Date: 18 September, 2013

Author: J. M. Fowkes

oBB is an algorithm for the parallel global optimization of functions with Lipchitz continuous gradient or Hessian.

- Installing oBB
  - Requirements
  - Installation using pip
  - Manual installation
  - Testing
  - Uninstallation
- User Guide
  - Global Optimization
  - How to use oBB
  - Optional Arguments
  - Example of Use
  - Running the Algorithm
  - Using the RBF Layer
  - RBF Layer for the COCONUT Test Set
  - Acknowledgements
  - References

## Acknowledgements

This work was supported by EPSRC grants EP/I028854/1 (PI: Dr Coralia Cartis) and NAIS EP/G036136/1. We are also grateful to Prof Nick Gould for his help and advice during development and Mehdi Towhidi for providing us with his PyQuadProg code.